@@ -45,6 +45,7 @@ sub get_runlevels
      "mandrake-9.0"     => "redhat-6.2",
      "conectiva-9"      => "redhat-6.2",
      "debian-3.0"       => "redhat-6.2",
+     "ubuntu-7.04"      => "redhat-6.2",
      "suse-9.0"         => "redhat-6.2",
      "pld-1.0"          => "redhat-6.2",
      "vine-3.0"         => "redhat-6.2",
@@ -100,6 +101,7 @@ sub get_sysv_paths
      "yoper-2.2"      => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
      "conectiva-9"    => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
      "debian-3.0"     => ["$gst_prefix/etc",      "$gst_prefix/etc/init.d",      "../init.d"],
+     "ubuntu-7.04"    => ["$gst_prefix/etc",      "$gst_prefix/etc/init.d",      "../init.d"],
      "suse-9.0"       => ["$gst_prefix/etc/init.d", "$gst_prefix/etc/init.d",    "../"],
      "pld-1.0"        => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
      "vine-3.0"       => ["$gst_prefix/etc/rc.d", "$gst_prefix/etc/rc.d/init.d", "../init.d"],
